AppCheck class
Properties
- app → FirebaseApp
-
The Firebase app this service is associated with.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createToken(
String appId, [AppCheckTokenOptions? options]) → Future< AppCheckToken> - Creates a new AppCheckToken that can be sent back to a client.
-
delete(
) → Future< void> - Cleans up resources used by this service.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
verifyToken(
String appCheckToken, [VerifyAppCheckTokenOptions? options]) → Future< VerifyAppCheckTokenResponse> - Verifies a Firebase App Check token (JWT). If the token is valid, the returned Future completes with the token's decoded claims; otherwise, it throws a FirebaseAppCheckException.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited