AppCheckErrorCode enum

Inheritance
Available extensions

Values

aborted → const AppCheckErrorCode
const AppCheckErrorCode('aborted')
invalidArgument → const AppCheckErrorCode
const AppCheckErrorCode('invalid-argument')
invalidCredential → const AppCheckErrorCode
const AppCheckErrorCode('invalid-credential')
internalError → const AppCheckErrorCode
const AppCheckErrorCode('internal-error')
permissionDenied → const AppCheckErrorCode
const AppCheckErrorCode('permission-denied')
unauthenticated → const AppCheckErrorCode
const AppCheckErrorCode('unauthenticated')
notFound → const AppCheckErrorCode
const AppCheckErrorCode('not-found')
appCheckTokenExpired → const AppCheckErrorCode
const AppCheckErrorCode('app-check-token-expired')
unknownError → const AppCheckErrorCode
const AppCheckErrorCode('unknown-error')

Properties

code String
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AppCheckErrorCode>
A constant List of the values in this enum, in order of their declaration.