FirebaseAppCheckException class
Firebase App Check error code structure. This extends PrefixedFirebaseError.
- Inheritance
-
- Object
- FirebaseAdminException
- FirebaseAppCheckException
Constructors
- FirebaseAppCheckException(AppCheckErrorCode code, [String? message])
- FirebaseAppCheckException.fromJwtException(JwtException error)
-
factory
Properties
- code → String
-
Error codes are strings using the following format:
"service/String-code". Some examples include"auth/invalid-uid"and"messaging/invalid-recipient".no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
An explanatory message for the error that just occurred.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- service → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts this exception to a JSON-serializable map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited