linkDomain property
Defines the link domain to use for the current link. This can be a custom domain configured in your Firebase project or a Firebase Dynamic Link domain. If none is provided, the oldest configured domain is used by default.
Implementation
final String? linkDomain;