AllowByDefaultSmsRegionConfig class

Defines a policy of allowing every region by default and adding disallowed regions to a disallow list.

Inheritance

Constructors

AllowByDefaultSmsRegionConfig({required List<String> disallowedRegions})
const

Properties

disallowedRegions List<String>
Two letter unicode region codes to disallow as defined by https://cldr.unicode.org/
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited