createSessionCookie method

Future<String> createSessionCookie(
  1. String idToken,
  2. SessionCookieOptions sessionCookieOptions
)
inherited

Creates a new Firebase session cookie with the specified options. The created JWT string can be set as a server-side session cookie with a custom cookie policy, and be used for session management. The session cookie JWT will have the same payload claims as the provided ID token.

See https://firebase.google.com/docs/auth/admin/manage-cookies for code samples and detailed documentation.

Implementation

Future<String> createSessionCookie(
  String idToken,
  SessionCookieOptions sessionCookieOptions,
) async {
  return _authRequestHandler.createSessionCookie(
    idToken,
    expiresIn: sessionCookieOptions.expiresIn,
  );
}