projectConfigManager property

ProjectConfigManager get projectConfigManager

The ProjectConfigManager instance associated with the current project.

This provides methods to get and update the project configuration, including SMS regions, multi-factor authentication, reCAPTCHA, password policy, email privacy, and mobile links settings.

Implementation

ProjectConfigManager get projectConfigManager {
  return _projectConfigManager ??= ProjectConfigManager._(app);
}