EmailSignInProviderConfig class

The email sign in provider configuration.

Constructors

EmailSignInProviderConfig({required bool enabled, bool? passwordRequired})

Properties

enabled bool
Whether email provider is enabled.
final
hashCode int
The hash code for this object.
no setterinherited
passwordRequired bool?
Whether password is required for email sign-in. When not required, email sign-in can be performed with password or via email link sign-in.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited