ListTenantsResult class

Interface representing the object returned from a TenantManager.listTenants operation. Contains the list of tenants for the current batch and the next page token if available.

Constructors

ListTenantsResult({required List<Tenant> tenants, String? pageToken})

Properties

hashCode → int
The hash code for this object.
no setterinherited
pageToken → String?
The next page token if available. This is needed for the next batch download.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tenants → List<Tenant>
The list of Tenant objects for the downloaded batch.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited