domain property
Use Firebase Hosting or dynamic link domain as the out-of-band code domain.
Implementation
final MobileLinksDomain? domain;
Use Firebase Hosting or dynamic link domain as the out-of-band code domain.
final MobileLinksDomain? domain;