ProjectConfigManager class
Manages (gets and updates) the current project config.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getProjectConfig(
) → Future< ProjectConfig> - Get the project configuration.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateProjectConfig(
UpdateProjectConfigRequest projectConfigOptions) → Future< ProjectConfig> - Updates an existing project configuration.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited