RecaptchaKey class

The reCAPTCHA key config.

Constructors

RecaptchaKey({required String key, RecaptchaKeyClientType? type})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
The reCAPTCHA site key.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type RecaptchaKeyClientType?
The key's client platform type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited