endScore property
The action will be enforced if the reCAPTCHA score of a request is larger than endScore.
Implementation
final double endScore;
The action will be enforced if the reCAPTCHA score of a request is larger than endScore.
final double endScore;