RecaptchaTollFraudManagedRule class

The managed rules for toll fraud provider, containing the enforcement status. The toll fraud provider contains all SMS related user flows.

Constructors

RecaptchaTollFraudManagedRule({required double startScore, RecaptchaAction? action})
const

Properties

action RecaptchaAction?
The action for reCAPTCHA-protected requests.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startScore double
The action will be enforced if the reCAPTCHA score of a request is larger than startScore.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited