startScore property
The action will be enforced if the reCAPTCHA score of a request is larger than startScore.
Implementation
final double startScore;
The action will be enforced if the reCAPTCHA score of a request is larger than startScore.
final double startScore;