SessionCookieOptions class

Interface representing the session cookie options needed for the _BaseAuth.createSessionCookie method.

Constructors

SessionCookieOptions({required int expiresIn})
Creates a new SessionCookieOptions with the specified expiration time.
const

Properties

expiresIn int
The session cookie custom expiration in milliseconds.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited