Tenant class

Represents a tenant configuration.

Multi-tenancy support requires Google Cloud's Identity Platform (GCIP). To learn more about GCIP, including pricing and features, see the GCIP documentation.

Before multi-tenancy can be used on a Google Cloud Identity Platform project, tenants must be allowed on that project via the Cloud Console UI.

A tenant configuration provides information such as the display name, tenant identifier and email authentication configuration. For OIDC/SAML provider configuration management, TenantAwareAuth instances should be used instead of a Tenant to retrieve the list of configured IdPs on a tenant. When configuring these providers, note that tenants will inherit allowed domains and authenticated redirect URIs of their parent project.

All other settings of a tenant will also be inherited. These will need to be managed from the Cloud Console UI.

Properties

anonymousSignInEnabled bool
Whether anonymous sign-in is enabled.
final
displayName String?
The tenant display name.
final
emailPrivacyConfig EmailPrivacyConfig?
The email privacy configuration for the tenant
final
emailSignInConfig EmailSignInProviderConfig?
The email sign in provider configuration.
no setter
hashCode int
The hash code for this object.
no setterinherited
multiFactorConfig MultiFactorConfig?
The multi-factor auth configuration on the current tenant.
no setter
passwordPolicyConfig PasswordPolicyConfig?
The password policy configuration for the tenant
no setter
recaptchaConfig RecaptchaConfig?
The recaptcha config auth configuration of the current tenant.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
smsRegionConfig SmsRegionConfig?
The SMS Regions Config to update a tenant. Configures the regions where users are allowed to send verification SMS. This is based on the calling code of the destination phone number.
final
tenantId String
The tenant identifier.
final
testPhoneNumbers Map<String, String>?
The map containing the test phone number / code pairs for the tenant.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a JSON-serializable representation of this object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited