recaptchaConfig property
RecaptchaConfig?
get
recaptchaConfig
The recaptcha config auth configuration of the current tenant.
Implementation
RecaptchaConfig? get recaptchaConfig => _recaptchaConfig;
The recaptcha config auth configuration of the current tenant.
RecaptchaConfig? get recaptchaConfig => _recaptchaConfig;