smsRegionConfig property
The SMS Regions Config to update a tenant. Configures the regions where users are allowed to send verification SMS. This is based on the calling code of the destination phone number.
Implementation
final SmsRegionConfig? smsRegionConfig;