TenantManager class

Defines the tenant manager used to help manage tenant related operations. This includes:

  • The ability to create, update, list, get and delete tenants for the underlying project.
  • Getting a TenantAwareAuth instance for running Auth related operations (user management, provider configuration management, token verification, email link generation, etc) in the context of a specified tenant.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

authForTenant(String tenantId) TenantAwareAuth
Returns a TenantAwareAuth instance bound to the given tenant ID.
createTenant(CreateTenantRequest tenantOptions) Future<Tenant>
Creates a new tenant. When creating new tenants, tenants that use separate billing and quota will require their own project and must be defined as full_service.
deleteTenant(String tenantId) Future<void>
Deletes an existing tenant.
getTenant(String tenantId) Future<Tenant>
Gets the tenant configuration for the tenant corresponding to a given tenantId.
listTenants({int maxResults = 1000, String? pageToken}) Future<ListTenantsResult>
Retrieves a list of tenants (single batch only) with a size of maxResults starting from the offset as specified by pageToken. This is used to retrieve all the tenants of a specified project in batches.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateTenant(String tenantId, UpdateTenantRequest tenantOptions) Future<Tenant>
Updates an existing tenant configuration.

Operators

operator ==(Object other) bool
The equality operator.
inherited