createTenant method

Future<Tenant> createTenant(
  1. CreateTenantRequest tenantOptions
)

Creates a new tenant. When creating new tenants, tenants that use separate billing and quota will require their own project and must be defined as full_service.

tenantOptions - The properties to set on the new tenant configuration to be created.

Returns a Future fulfilled with the tenant configuration corresponding to the newly created tenant.

Implementation

Future<Tenant> createTenant(CreateTenantRequest tenantOptions) async {
  final response = await _authRequestHandler.createTenant(tenantOptions);
  return Tenant._fromResponse(response);
}