getTenant method

Future<Tenant> getTenant(
  1. String tenantId
)

Gets the tenant configuration for the tenant corresponding to a given tenantId.

tenantId - The tenant identifier corresponding to the tenant whose data to fetch.

Returns a Future fulfilled with the tenant configuration for the provided tenantId.

Implementation

Future<Tenant> getTenant(String tenantId) async {
  final response = await _authRequestHandler.getTenant(tenantId);
  return Tenant._fromResponse(response);
}