TotpInfo class

Represents TOTP (Time-based One-time Password) information for second factor authentication. This class is used with authenticator apps like Google Authenticator, Authy, etc. It serves as a marker class with no additional properties beyond what's inherited from MultiFactorInfo.

Constructors

TotpInfo()
Creates a new TotpInfo instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited