TotpMultiFactorProviderConfig class

Interface representing configuration settings for TOTP second factor auth.

Constructors

TotpMultiFactorProviderConfig({int? adjacentIntervals})
Creates a new TotpMultiFactorProviderConfig instance.

Properties

adjacentIntervals int?
The allowed number of adjacent intervals that will be used for verification to compensate for clock skew. Valid range is 0-10 (inclusive).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited