adjacentIntervals property

int? adjacentIntervals
final

The allowed number of adjacent intervals that will be used for verification to compensate for clock skew. Valid range is 0-10 (inclusive).

Implementation

final int? adjacentIntervals;