emailPrivacyConfig property
The email privacy configuration to update on the project.
Implementation
final EmailPrivacyConfig? emailPrivacyConfig;
The email privacy configuration to update on the project.
final EmailPrivacyConfig? emailPrivacyConfig;