testPhoneNumbers property

Map<String, String>? testPhoneNumbers
final

The updated map containing the test phone number / code pairs for the tenant. Passing null clears the previously saved phone number / code pairs.

Implementation

final Map<String, String>? testPhoneNumbers;