securityRules method

SecurityRules securityRules()

Gets the Security Rules service instance for this app.

Returns a cached instance if one exists, otherwise creates a new one.

Implementation

SecurityRules securityRules() => SecurityRules.internal(this);