Firestore class

Firestore service for Firebase Admin SDK.

Properties

app FirebaseApp
The Firebase app this service is associated with.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildSettingsForTesting(String databaseId, Settings? userSettings) → Settings
Gets the actual settings that would be built for a database. This calls _buildSettings without initializing the database.
delete() Future<void>
Cleans up resources used by this service.
getSettingsForDatabase(String databaseId) → Settings?
Gets the settings used to initialize a specific database. Returns null if the database hasn't been initialized yet.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited