functions library

Classes

AbsoluteDelivery
Schedules task delivery at an absolute time.
DelayDelivery
Schedules task delivery after a delay from the current time.
DeliverySchedule
Represents delivery scheduling options for a task.
Functions
An interface for interacting with Cloud Functions Task Queues.
FunctionScope
Represents the scope of a function in a task queue.
FunctionsHttpClient
HTTP client for Cloud Functions Task Queue operations.
FunctionsRequestHandler
Request handler for Cloud Functions Task Queue operations.
TaskOptions
Options for enqueuing a task.
TaskOptionsExperimental
Experimental (beta) task options.
TaskQueue
A reference to a Cloud Functions task queue.

Enums

FunctionsClientErrorCode
Functions client error codes and their default messages.

Exceptions / Errors

FirebaseFunctionsAdminException
Exception thrown by Firebase Functions operations.