AbsoluteDelivery class
Schedules task delivery at an absolute time.
The task will be attempted or retried at the specified scheduleTime.
- Inheritance
-
- Object
- DeliverySchedule
- AbsoluteDelivery
Constructors
- AbsoluteDelivery(DateTime scheduleTime)
-
Creates an absolute delivery schedule.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheduleTime → DateTime
-
The time when the task is scheduled to be attempted or retried.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited