DeliverySchedule class sealed

Represents delivery scheduling options for a task.

Use AbsoluteDelivery to schedule a task at a specific time, or DelayDelivery to schedule a task after a delay from the current time.

This is a sealed class, ensuring compile-time exhaustiveness checking when pattern matching.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited