FirebaseFunctionsAdminException class

Exception thrown by Firebase Functions operations.

Inheritance
Implemented types

Constructors

FirebaseFunctionsAdminException(FunctionsClientErrorCode errorCode, [String? message])
Creates a Functions exception with the given error code and message.

Properties

code String
Error codes are strings using the following format: "service/String-code". Some examples include "auth/invalid-uid" and "messaging/invalid-recipient".
no setterinherited
errorCode FunctionsClientErrorCode
The error code for this exception.
final
hashCode int
The hash code for this object.
no setterinherited
message String
An explanatory message for the error that just occurred.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
service String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this exception to a JSON-serializable map.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited