FunctionScope class sealed

Represents the scope of a function in a task queue.

Constructors

FunctionScope.current()
Targets a function co-deployed in the same codebase/deployment context.
const
factory
FunctionScope.extension(String extensionId)
Targets a function deployed within a specific Firebase Extension.
const
factory
FunctionScope.global()
Targets a global function (e.g. without kit or extension namespacing).
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited