Functions class

An interface for interacting with Cloud Functions Task Queues.

This service allows you to enqueue tasks for Cloud Functions and manage those tasks before they execute.

Properties

app → FirebaseApp
The app associated with this Functions instance.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete() → Future<void>
Cleans up resources used by this service.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
taskQueue(String functionName, {String? extensionId, FunctionScope? scope}) → TaskQueue
Creates a reference to a task queue for the given function.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited