FunctionsClientErrorCode enum

Functions client error codes and their default messages.

Inheritance
Available extensions

Values

invalidArgument → const FunctionsClientErrorCode

Invalid argument provided.

const FunctionsClientErrorCode(code: 'invalid-argument', message: 'Invalid argument provided.')
invalidCredential → const FunctionsClientErrorCode

Invalid credential.

const FunctionsClientErrorCode(code: 'invalid-credential', message: 'Invalid credential.')
internalError → const FunctionsClientErrorCode

Internal server error.

const FunctionsClientErrorCode(code: 'internal-error', message: 'Internal server error.')
failedPrecondition → const FunctionsClientErrorCode

Failed precondition.

const FunctionsClientErrorCode(code: 'failed-precondition', message: 'Failed precondition.')
permissionDenied → const FunctionsClientErrorCode

Permission denied.

const FunctionsClientErrorCode(code: 'permission-denied', message: 'Permission denied.')
unauthenticated → const FunctionsClientErrorCode

Unauthenticated.

const FunctionsClientErrorCode(code: 'unauthenticated', message: 'Unauthenticated.')
notFound → const FunctionsClientErrorCode

Resource not found.

const FunctionsClientErrorCode(code: 'not-found', message: 'Resource not found.')
unknownError → const FunctionsClientErrorCode

Unknown error.

const FunctionsClientErrorCode(code: 'unknown-error', message: 'Unknown error.')
taskAlreadyExists → const FunctionsClientErrorCode

Task with the given ID already exists.

const FunctionsClientErrorCode(code: 'task-already-exists', message: 'Task already exists.')
aborted → const FunctionsClientErrorCode

Request aborted.

const FunctionsClientErrorCode(code: 'aborted', message: 'Request aborted.')

Properties

code String
The error code string.
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
message String
The default error message.
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FunctionsClientErrorCode>
A constant List of the values in this enum, in order of their declaration.