FunctionsRequestHandler class

Request handler for Cloud Functions Task Queue operations.

Handles complex business logic, request/response transformations, and validation. Delegates API calls to FunctionsHttpClient.

Constructors

FunctionsRequestHandler(FirebaseApp app, {FunctionsHttpClient? httpClient})

Properties

hashCode int
The hash code for this object.
no setterinherited
httpClient FunctionsHttpClient
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String id, String functionName, String? extensionId) Future<void>
Deletes a task from the specified function's queue.
enqueue(Map<String, dynamic> data, String functionName, String? extensionId, TaskOptions? options) Future<void>
Enqueues a task to the specified function's queue.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited