TaskOptions class

Options for enqueuing a task.

Specifies scheduling, delivery, and identification options for a task.

Constructors

TaskOptions({DeliverySchedule? schedule, int? dispatchDeadlineSeconds, String? id, Map<String, String>? headers, TaskOptionsExperimental? experimental})
Creates task options with the specified configuration.

Properties

dispatchDeadlineSeconds → int?
The deadline for requests sent to the worker.
final
experimental → TaskOptionsExperimental?
Experimental (beta) task options.
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>?
HTTP request headers to include in the request to the task queue function.
final
id → String?
The ID to use for the enqueued task.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedule → DeliverySchedule?
Optional delivery schedule for the task.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited