dispatchDeadlineSeconds property
The deadline for requests sent to the worker.
If the worker does not respond by this deadline then the request is cancelled and the attempt is marked as a DEADLINE_EXCEEDED failure. Cloud Tasks will retry the task according to the RetryConfig.
The default is 10 minutes (600 seconds). The deadline must be in the range of 15 seconds to 30 minutes (1800 seconds).
Implementation
final int? dispatchDeadlineSeconds;