schedule property
Optional delivery schedule for the task.
Use AbsoluteDelivery to schedule at a specific time, or DelayDelivery to schedule after a delay.
If not specified, the task will be enqueued immediately.
Implementation
final DeliverySchedule? schedule;