TaskOptionsExperimental class

Experimental (beta) task options.

These options may change in future releases.

Constructors

TaskOptionsExperimental({String? uri})
Creates experimental task options.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → String?
The full URL path that the request will be sent to.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited