uri property
The full URL path that the request will be sent to.
Must be a valid URL.
Beta feature - May change in future releases.
Implementation
final String? uri;
The full URL path that the request will be sent to.
Must be a valid URL.
Beta feature - May change in future releases.
final String? uri;