TaskQueue class

A reference to a Cloud Functions task queue.

Use this to enqueue tasks for a specific Cloud Function or delete pending tasks.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String id) Future<void>
Deletes a task from the queue by its id.
enqueue(Map<String, dynamic> data, [TaskOptions? options]) Future<void>
Enqueues a task with the given data payload.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited