messaging library

Classes

AndroidConfig
Represents the Android-specific options that can be included in an Message.
AndroidFcmOptions
Represents options for features provided by the FCM SDK for Android.
AndroidNotification
Represents the Android-specific notification options that can be included in AndroidConfig.
ApnsConfig
Represents the APNs-specific options that can be included in an Message. Refer to Apple documentation for various headers and payload fields supported by APNs.
ApnsFcmOptions
Represents options for features provided by the FCM SDK for iOS.
ApnsPayload
Represents the payload of an APNs message. Mainly consists of the aps dictionary.
Aps
Represents the aps dictionary that is part of APNs messages.
ApsAlert
ApsSound
Base class for the APNs sound field.
ApsSoundName
A simple sound name for an APNs notification.
BatchResponse
Interface representing the server response from the Messaging.sendEach and Messaging.sendEachForMulticast methods.
ConditionMessage
A message targeting a condition.
CriticalSound
Represents a critical sound configuration that can be included in the aps dictionary of an APNs payload.
FcmOptions
Represents platform-independent options for features provided by the FCM SDKs.
LightSettings
Represents settings to control notification LED that can be included in AndroidNotification.
Message
Payload for the Messaging.send operation. The payload contains all the fields in the BaseMessage type, and exactly one of token, topic or condition.
Messaging
An interface for interacting with the Firebase Cloud Messaging service.
MessagingTopicManagementResponse
Interface representing the server response from the Messaging.subscribeToTopic and Messaging.unsubscribeFromTopic methods.
MessagingTopicResponse
Interface representing the server response from the legacy {@link Messaging.sendToTopic} method.
MulticastMessage
Payload for the Messaging.sendEachForMulticast method. The payload contains all the fields in the BaseMessage type, and a list of tokens.
Notification
A notification that can be included in Message.
SendResponse
Interface representing the status of an individual message that was sent as part of a batch request.
TokenMessage
A message targeting a specific registration token.
TopicMessage
A message targeting a topic.
WebpushConfig
Represents the WebPush protocol options that can be included in a Message.
WebpushFcmOptions
Represents options for features provided by the FCM SDK for Web (which are not part of the Webpush standard).
WebpushNotification
Represents the WebPush-specific notification options that can be included in WebpushConfig. This supports most of the standard options as defined in the Web Notification specification.
WebpushNotificationAction

Enums

AndroidConfigPriority
AndroidNotificationPriority
AndroidNotificationProxy
Enum representing proxy behaviors for Android notifications.
AndroidNotificationVisibility
ApsInterruptionLevel
The interruption level of an APNs notification, as defined by Apple.
MessagingClientErrorCode
Messaging client error codes and their default messages.
WebpushNotificationDirection

Exceptions / Errors

FirebaseMessagingAdminException