directBootOk property

bool? directBootOk
final

A boolean indicating whether messages will be allowed to be delivered to the app while the device is in direct boot mode.

Implementation

final bool? directBootOk;