AndroidNotification class

Represents the Android-specific notification options that can be included in AndroidConfig.

Constructors

AndroidNotification({String? title, String? body, String? icon, String? color, String? sound, String? tag, String? imageUrl, String? clickAction, String? bodyLocKey, List<String>? bodyLocArgs, String? titleLocKey, List<String>? titleLocArgs, String? channelId, String? ticker, bool? sticky, DateTime? eventTimestamp, bool? localOnly, AndroidNotificationPriority? priority, List<String>? vibrateTimingsMillis, bool? defaultVibrateTimings, bool? defaultSound, LightSettings? lightSettings, bool? defaultLightSettings, AndroidNotificationVisibility? visibility, int? notificationCount, AndroidNotificationProxy? proxy})
Represents the Android-specific notification options that can be included in AndroidConfig.

Properties

body → String?
Body of the Android notification. When provided, overrides the body set via admin.messaging.Notification.
final
bodyLocArgs → List<String>?
An array of resource keys that will be used in place of the format specifiers in bodyLocKey.
final
bodyLocKey → String?
Key of the body string in the app's string resource to use to localize the body text.
final
channelId → String?
The Android notification channel ID (new in Android O). The app must create a channel with this channel ID before any notification with this channel ID can be received. If you don't send this channel ID in the request, or if the channel ID provided has not yet been created by the app, FCM uses the channel ID specified in the app manifest.
final
clickAction → String?
Action associated with a user click on the notification. If specified, an activity with a matching Intent Filter is launched when a user clicks on the notification.
final
color → String?
Notification icon color in #rrggbb format.
final
defaultLightSettings → bool?
If set to true, use the Android framework's default LED light settings for the notification. Default values are specified in config.xml. If default_light_settings is set to true and light_settings is also set, the user-specified light_settings is used instead of the default value.
final
defaultSound → bool?
If set to true, use the Android framework's default sound for the notification. Default values are specified in config.xml.
final
defaultVibrateTimings → bool?
If set to true, use the Android framework's default vibrate pattern for the notification. Default values are specified in config.xml. If default_vibrate_timings is set to true and vibrate_timings is also set, the default value is used instead of the user-specified vibrate_timings.
final
eventTimestamp → DateTime?
For notifications that inform users about events with an absolute time reference, sets the time that the event in the notification occurred. Notifications in the panel are sorted by this time.
final
hashCode → int
The hash code for this object.
no setterinherited
icon → String?
Icon resource for the Android notification.
final
imageUrl → String?
URL of an image to be displayed in the notification.
final
lightSettings → LightSettings?
Settings to control the notification's LED blinking rate and color if LED is available on the device. The total blinking time is controlled by the OS.
final
localOnly → bool?
Sets whether or not this notification is relevant only to the current device. Some notifications can be bridged to other devices for remote display, such as a Wear OS watch. This hint can be set to recommend this notification not be bridged. See Wear OS guides.
final
notificationCount → int?
Sets the number of items this notification represents. May be displayed as a badge count for Launchers that support badging. See NotificationBadge. For example, this might be useful if you're using just one notification to represent multiple new messages but you want the count here to represent the number of total new messages. If zero or unspecified, systems that support badging use the default, which is to increment a number displayed on the long-press menu each time a new notification arrives.
final
priority → AndroidNotificationPriority?
Sets the relative priority for this notification. Low-priority notifications may be hidden from the user in certain situations. Note this priority differs from AndroidMessagePriority. This priority is processed by the client after the message has been delivered. Whereas AndroidMessagePriority is an FCM concept that controls when the message is delivered.
final
proxy → AndroidNotificationProxy?
Sets proxy option for the notification. Proxy can be allow, deny, or ifPriorityLowered. This controls whether the notification can be proxied to other devices.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sound → String?
File name of the sound to be played when the device receives the notification.
final
sticky → bool?
When set to false or unset, the notification is automatically dismissed when the user clicks it in the panel. When set to true, the notification persists even when the user clicks it.
final
tag → String?
Notification tag. This is an identifier used to replace existing notifications in the notification drawer. If not specified, each request creates a new notification.
final
ticker → String?
Sets the "ticker" text, which is sent to accessibility services. Prior to API level 21 (Lollipop), sets the text that is displayed in the status bar when the notification first arrives.
final
title → String?
Title of the Android notification. When provided, overrides the title set via admin.messaging.Notification.
final
titleLocArgs → List<String>?
An array of resource keys that will be used in place of the format specifiers in titleLocKey.
final
titleLocKey → String?
Key of the title string in the app's string resource to use to localize the title text.
final
vibrateTimingsMillis → List<String>?
Sets the vibration pattern to use. Pass in an array of milliseconds to turn the vibrator on or off. The first value indicates the duration to wait before turning the vibrator on. The next value indicates the duration to keep the vibrator on. Subsequent values alternate between duration to turn the vibrator off and to turn the vibrator on. If vibrate_timings is set and default_vibrate_timings is set to true, the default value is used instead of the user-specified vibrate_timings.
final
visibility → AndroidNotificationVisibility?
Sets the visibility of the notification. Must be either private, public, or secret. If unspecified, defaults to private.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited