Aps class

Represents the aps dictionary that is part of APNs messages.

Constructors

Aps({ApsAlert? alert, num? badge, ApsSound? sound, bool? contentAvailable, bool? mutableContent, String? category, String? threadId, ApsInterruptionLevel? interruptionLevel})

Properties

alert ApsAlert?
Alert to be included in the message. This may be a string or an object of type admin.messaging.ApsAlert.
final
badge num?
Badge to be displayed with the message. Set to 0 to remove the badge. When not specified, the badge will remain unchanged.
final
category String?
Type of the notification.
final
contentAvailable bool?
Specifies whether to configure a background update notification.
final
hashCode int
The hash code for this object.
no setterinherited
interruptionLevel ApsInterruptionLevel?
The interruption level of the notification.
final
mutableContent bool?
Specifies whether to set the mutable-content property on the message so the clients can modify the notification via app extensions.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sound ApsSound?
Sound to be played with the message. May be a simple sound name via ApsSoundName or a critical alert configuration via CriticalSound.
final
threadId String?
An app-specific identifier for grouping notifications.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited