CriticalSound class final

Represents a critical sound configuration that can be included in the aps dictionary of an APNs payload.

Requires the Critical Alerts entitlement. For a simple sound name, use ApsSoundName instead.

Inheritance

Constructors

CriticalSound({bool? critical, required String name, double? volume})
const

Properties

critical → bool?
The critical alert flag. Set to true to enable the critical alert.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of a sound file in the app's main bundle or in the Library/Sounds folder of the app's container directory. Specify the string "default" to play the system sound.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
volume → double?
The volume for the critical alert's sound. Must be a value between 0.0 (silent) and 1.0 (full volume).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited