MessagingTopicManagementResponse class

Interface representing the server response from the Messaging.subscribeToTopic and Messaging.unsubscribeFromTopic methods.

Properties

errors List<FirebaseArrayIndexError>
An array of errors corresponding to the provided registration token(s). The length of this array will be equal to failureCount.
final
failureCount int
The number of registration tokens that could not be subscribed to the topic and resulted in an error.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
successCount int
The number of registration tokens that were successfully subscribed to the topic.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited