errors property

An array of errors corresponding to the provided registration token(s). The length of this array will be equal to failureCount.

Implementation

final List<FirebaseArrayIndexError> errors;