failureCount property
The number of registration tokens that could not be subscribed to the topic and resulted in an error.
Implementation
final int failureCount;
The number of registration tokens that could not be subscribed to the topic and resulted in an error.
final int failureCount;