successCount property
The number of registration tokens that were successfully subscribed to the topic.
Implementation
final int successCount;
The number of registration tokens that were successfully subscribed to the topic.
final int successCount;