WebpushFcmOptions class

Represents options for features provided by the FCM SDK for Web (which are not part of the Webpush standard).

Constructors

WebpushFcmOptions({String? link})
Represents options for features provided by the FCM SDK for Web (which are not part of the Webpush standard).

Properties

hashCode → int
The hash code for this object.
no setterinherited
The link to open when the user clicks on the notification. For all URL values, HTTPS is required.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited