ListRulesetsResponse class

Constructors

ListRulesetsResponse.forTest({required List<RulesetResponse> rulesets, String? nextPageToken})
Factory constructor for testing purposes.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken → String?
final
rulesets → List<RulesetResponse>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited