RulesetResponse class
- Inheritance
-
- Object
- RulesetContent
- RulesetResponse
Constructors
- RulesetResponse.forTest({required String name, required String createTime, required RulesetSource source})
-
Factory constructor for testing purposes.
factory
Properties
- createTime → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → RulesetSource
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited