releaseStorageRuleset method

Future<void> releaseStorageRuleset(
  1. String ruleset, [
  2. String? bucket
])

Applies the specified Ruleset ruleset to a Cloud Storage bucket.

ruleset - Name of the ruleset to apply. bucket - Optional name of the Cloud Storage bucket to apply the rules on. If not specified, applies the ruleset on the default bucket configured via AppOptions.storageBucket. Returns a future that fulfills when the ruleset is released.

Implementation

Future<void> releaseStorageRuleset(String ruleset, [String? bucket]) async {
  final bucketName = _getBucketName(bucket);
  await _requestHandler.updateOrCreateRelease(
    '$_firebaseStorage/$bucketName',
    ruleset,
  );
}