Storage class
Properties
- app → FirebaseApp
-
The Firebase app this service is associated with.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bucket(
[String? name]) → Bucket -
delete(
) → Future< void> - Cleans up resources used by this service.
-
getDownloadURL(
Bucket bucket, String objectName) → Future< String> - Returns a long-lived download URL for the given object.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited