StorageClientErrorCode enum
Values
- noDownloadToken → const StorageClientErrorCode
-
const StorageClientErrorCode(code: 'no-download-token', message: 'No download token available. Please create one in the Firebase Console.') - objectNotFound → const StorageClientErrorCode
-
const StorageClientErrorCode(code: 'object-not-found', message: 'No object exists at the desired reference.') - internalError → const StorageClientErrorCode
-
const StorageClientErrorCode(code: 'internal-error', message: 'An internal error has occurred. Please retry the request.')
Properties
- code → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- message → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
StorageClientErrorCode> - A constant List of the values in this enum, in order of their declaration.