AllowlistOnlySmsRegionConfig class
Defines a policy of only allowing regions by explicitly adding them to an allowlist.
- Inheritance
-
- Object
- SmsRegionConfig
- AllowlistOnlySmsRegionConfig
Constructors
-
AllowlistOnlySmsRegionConfig({required List<
String> allowedRegions}) -
const
Properties
-
allowedRegions
→ List<
String> -
Two letter unicode region codes to allow as defined by
https://cldr.unicode.org/
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited