CustomStrengthOptionsConfig class
Constraints to be enforced on the password policy
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxLength → int?
-
Maximum password length. No default max length
final
- minLength → int?
-
Minimum password length. Valid values are from 6 to 30
final
- requireLowercase → bool?
-
The password must contain a lower case character
final
- requireNonAlphanumeric → bool?
-
The password must contain a non-alphanumeric character
final
- requireNumeric → bool?
-
The password must contain a number
final
- requireUppercase → bool?
-
The password must contain an upper case character
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited