MobileLinksConfig class
Configuration for mobile links (app links and universal links).
Constructors
- MobileLinksConfig({MobileLinksDomain? domain})
-
const
Properties
- domain → MobileLinksDomain?
-
Use Firebase Hosting or dynamic link domain as the out-of-band code domain.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited