MultiFactorConfig class
Interface representing a multi-factor configuration.
Constructors
-
MultiFactorConfig({required MultiFactorConfigState state, List<
AuthFactorType> ? factorIds, List<MultiFactorProviderConfig> ? providerConfigs})
Properties
-
factorIds
→ List<
AuthFactorType> ? -
The list of identifiers for enabled second factors.
Currently 'phone' and 'totp' are supported.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
providerConfigs
→ List<
MultiFactorProviderConfig> ? -
The configuration for multi-factor auth providers.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → MultiFactorConfigState
-
The multi-factor config state.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited