MultiFactorProviderConfig class

Interface representing a multi-factor auth provider configuration. This interface is used for second factor auth providers other than SMS. Currently, only TOTP is supported.

Constructors

MultiFactorProviderConfig({required MultiFactorConfigState state, TotpMultiFactorProviderConfig? totpProviderConfig})
Creates a new MultiFactorProviderConfig instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state MultiFactorConfigState
Indicates whether this multi-factor provider is enabled or disabled.
final
totpProviderConfig TotpMultiFactorProviderConfig?
TOTP multi-factor provider config.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited