PasswordPolicyConfig class
A password policy configuration for a project or tenant
Constructors
- PasswordPolicyConfig({PasswordPolicyEnforcementState? enforcementState, bool? forceUpgradeOnSignin, CustomStrengthOptionsConfig? constraints})
Properties
- constraints → CustomStrengthOptionsConfig?
-
The constraints that make up the password strength policy
final
- enforcementState → PasswordPolicyEnforcementState?
-
Enforcement state of the password policy
final
- forceUpgradeOnSignin → bool?
-
Require users to have a policy-compliant password to sign in
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited