ProjectConfig class
Represents a project configuration.
Constructors
- ProjectConfig({SmsRegionConfig? smsRegionConfig, MultiFactorConfig? multiFactorConfig, RecaptchaConfig? recaptchaConfig, PasswordPolicyConfig? passwordPolicyConfig, EmailPrivacyConfig? emailPrivacyConfig, MobileLinksConfig? mobileLinksConfig})
-
const
-
ProjectConfig.fromServerResponse(Map<
String, dynamic> response) -
Creates a ProjectConfig from a server response.
factory
Properties
- emailPrivacyConfig → EmailPrivacyConfig?
-
The email privacy configuration for the project.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mobileLinksConfig → MobileLinksConfig?
-
The mobile links configuration for the project.
final
- multiFactorConfig → MultiFactorConfig?
-
The project's multi-factor auth configuration.
Supports only phone and TOTP.
final
- passwordPolicyConfig → PasswordPolicyConfig?
-
The password policy configuration for the project.
final
- recaptchaConfig → RecaptchaConfig?
-
The reCAPTCHA configuration for the project.
By enabling reCAPTCHA Enterprise integration, you are
agreeing to the reCAPTCHA Enterprise
Terms of Service.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- smsRegionConfig → SmsRegionConfig?
-
The SMS Regions Config for the project.
Configures the regions where users are allowed to send verification SMS.
This is based on the calling code of the destination phone number.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Returns a JSON-serializable representation of this object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited