smsRegionConfig property

SmsRegionConfig? smsRegionConfig
final

The SMS Regions Config for the project. Configures the regions where users are allowed to send verification SMS. This is based on the calling code of the destination phone number.

Implementation

final SmsRegionConfig? smsRegionConfig;