RecaptchaConfig class
The request interface for updating a reCAPTCHA Config. By enabling reCAPTCHA Enterprise Integration you are agreeing to reCAPTCHA Enterprise Terms of Service.
Constructors
-
RecaptchaConfig({RecaptchaProviderEnforcementState? emailPasswordEnforcementState, RecaptchaProviderEnforcementState? phoneEnforcementState, List<
RecaptchaManagedRule> ? managedRules, List<RecaptchaKey> ? recaptchaKeys, bool? useAccountDefender, bool? useSmsBotScore, bool? useSmsTollFraudProtection, List<RecaptchaTollFraudManagedRule> ? smsTollFraudManagedRules})
Properties
- emailPasswordEnforcementState → RecaptchaProviderEnforcementState?
-
The enforcement state of the email password provider.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
managedRules
→ List<
RecaptchaManagedRule> ? -
The reCAPTCHA managed rules.
final
- phoneEnforcementState → RecaptchaProviderEnforcementState?
-
The enforcement state of the phone provider.
final
-
recaptchaKeys
→ List<
RecaptchaKey> ? -
The reCAPTCHA keys.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
smsTollFraudManagedRules
→ List<
RecaptchaTollFraudManagedRule> ? -
The managed rules for toll fraud provider, containing the enforcement status.
The toll fraud provider contains all SMS related user flows.
final
- useAccountDefender → bool?
-
Whether to use account defender for reCAPTCHA assessment.
final
- useSmsBotScore → bool?
-
Whether to use the rCE bot score for reCAPTCHA phone provider.
Can only be true when the phone_enforcement_state is AUDIT or ENFORCE.
final
- useSmsTollFraudProtection → bool?
-
Whether to use the rCE SMS toll fraud protection risk score for reCAPTCHA phone provider.
Can only be true when the phone_enforcement_state is AUDIT or ENFORCE.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited