RecaptchaManagedRule class
The config for a reCAPTCHA action rule.
Constructors
- RecaptchaManagedRule({required double endScore, RecaptchaAction? action})
-
const
Properties
- action → RecaptchaAction?
-
The action for reCAPTCHA-protected requests.
final
- endScore → double
-
The action will be enforced if the reCAPTCHA score of a request is larger than endScore.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited