UpdateProjectConfigRequest class
Interface representing the properties to update on the provided project config.
Constructors
- UpdateProjectConfigRequest({SmsRegionConfig? smsRegionConfig, MultiFactorConfig? multiFactorConfig, RecaptchaConfig? recaptchaConfig, PasswordPolicyConfig? passwordPolicyConfig, EmailPrivacyConfig? emailPrivacyConfig, MobileLinksConfig? mobileLinksConfig})
-
const
Properties
- emailPrivacyConfig → EmailPrivacyConfig?
-
The email privacy configuration to update on the project.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mobileLinksConfig → MobileLinksConfig?
-
The mobile links configuration for the project.
final
- multiFactorConfig → MultiFactorConfig?
-
The multi-factor auth configuration to update on the project.
final
- passwordPolicyConfig → PasswordPolicyConfig?
-
The password policy configuration to update on the project.
final
- recaptchaConfig → RecaptchaConfig?
-
The reCAPTCHA configuration to update on the project.
By enabling reCAPTCHA Enterprise integration, you are
agreeing to the reCAPTCHA Enterprise
Terms of Service.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- smsRegionConfig → SmsRegionConfig?
-
The SMS configuration to update on the project.
final
Methods
-
buildServerRequest(
) → Map< String, dynamic> - Builds the server request from this config request.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → void - Validates the request. Throws an error on failure.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited