UpdateTenantRequest class
Interface representing the properties to update on the provided tenant.
Constructors
-
UpdateTenantRequest({String? displayName, EmailSignInProviderConfig? emailSignInConfig, bool? anonymousSignInEnabled, MultiFactorConfig? multiFactorConfig, Map<
String, String> ? testPhoneNumbers, SmsRegionConfig? smsRegionConfig, RecaptchaConfig? recaptchaConfig, PasswordPolicyConfig? passwordPolicyConfig, EmailPrivacyConfig? emailPrivacyConfig})
Properties
- anonymousSignInEnabled → bool?
-
Whether the anonymous provider is enabled.
final
- displayName → String?
-
The tenant display name.
final
- emailPrivacyConfig → EmailPrivacyConfig?
-
The email privacy configuration for the tenant
final
- emailSignInConfig → EmailSignInProviderConfig?
-
The email sign in configuration.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- multiFactorConfig → MultiFactorConfig?
-
The multi-factor auth configuration to update on the tenant.
final
- passwordPolicyConfig → PasswordPolicyConfig?
-
The password policy configuration for the tenant
final
- recaptchaConfig → RecaptchaConfig?
-
The reCAPTCHA configuration to update on the tenant.
By enabling reCAPTCHA Enterprise integration, you are
agreeing to the reCAPTCHA Enterprise
Terms of Service.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- smsRegionConfig → SmsRegionConfig?
-
The SMS configuration to update on the project.
final
-
testPhoneNumbers
→ Map<
String, String> ? -
The updated map containing the test phone number / code pairs for the tenant.
Passing null clears the previously saved phone number / code pairs.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited