FirebaseApp class
Represents a Firebase app instance.
Each app is associated with a Firebase project and has its own configuration options and services.
Constructors
- FirebaseApp({required AppOptions options, required String name, required bool wasInitializedFromEnv})
Properties
-
client
→ Future<
AuthClient> -
The authenticated HTTP client for this app.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDeleted → bool
-
Returns true if this app has been deleted.
no setter
- name → String
-
The name of this app.
final
- options → AppOptions
-
The configuration options for this app.
final
- projectId → String?
-
Returns the explicitly configured project ID, if available.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wasInitializedFromEnv → bool
-
Whether this app was initialized from environment variables.
final
Methods
-
appCheck(
) → AppCheck - Gets the App Check service instance for this app.
-
auth(
) → Auth - Gets the Auth service instance for this app.
-
close(
) → Future< void> - Closes this app and cleans up all associated resources.
-
firestore(
{Settings? settings, String databaseId = kDefaultDatabaseId}) → Firestore - Gets the Firestore service instance for this app.
-
functions(
) → Functions - Gets the Functions service instance for this app.
-
messaging(
) → Messaging - Gets the Messaging service instance for this app.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
securityRules(
) → SecurityRules - Gets the Security Rules service instance for this app.
-
storage(
) → Storage - Gets the Storage service instance for this app.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
apps
→ List<
FirebaseApp> -
Returns a list of all initialized Firebase apps.
no setter
- instance → FirebaseApp
-
Returns the default Firebase app instance.
no setter
Static Methods
-
deleteApp(
FirebaseApp app) → Future< void> - Deletes the specified Firebase app and cleans up its resources.
-
getApp(
[String? name]) → FirebaseApp - Gets an existing Firebase app by name.
-
initializeApp(
{AppOptions? options, String? name}) → FirebaseApp - Initializes a Firebase app.