DelayDelivery class
Schedules task delivery after a delay from the current time.
The task will be attempted after scheduleDelaySeconds seconds from now.
- Inheritance
-
- Object
- DeliverySchedule
- DelayDelivery
Constructors
- DelayDelivery(int scheduleDelaySeconds)
- Creates a delayed delivery schedule.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheduleDelaySeconds → int
-
The duration of delay (in seconds) before the task is scheduled
to be attempted.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited