taskQueue method
TaskQueue
taskQueue(
- String functionName, {
- @Deprecated('Use scope instead. Will be removed in a future major version.') String? extensionId,
- FunctionScope? scope,
Creates a reference to a task queue for the given function.
The functionName can be:
- A fully qualified function resource name:
projects/{project}/locations/{location}/functions/{functionName} - A partial resource name with location and function name:
locations/{location}/functions/{functionName} - Just the function name (uses default location
us-central1):{functionName}
The optional extensionId is used for Firebase Extension functions.
Example:
final functions = FirebaseApp.instance.functions;
final queue = functions.taskQueue('myFunction');
await queue.enqueue({'data': 'value'});
Implementation
TaskQueue taskQueue(
String functionName, {
@Deprecated('Use scope instead. Will be removed in a future major version.')
String? extensionId,
FunctionScope? scope,
}) {
return TaskQueue._(
functionName: functionName,
requestHandler: _requestHandler,
extensionId: extensionId,
scope: scope,
);
}