FunctionsHttpClient class
HTTP client for Cloud Functions Task Queue operations.
Handles HTTP client management, googleapis API client creation, path builders, and emulator support.
Constructors
Properties
- app → FirebaseApp
-
final
-
client
→ Future<
AuthClient> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildFunctionUrl(
{required String projectId, required String locationId, required String functionName}) → String - Builds the function URL.
-
buildTaskName(
{required String projectId, required String locationId, required String queueId, required String taskId}) → String - Builds the full task resource name.
-
buildTasksParent(
{required String projectId, required String locationId, required String queueId}) → String - Builds the parent resource path for Cloud Tasks operations.
-
cloudTasks<
R> (Future< R> fn(CloudTasksApi api, String projectId)) → Future<R> - Executes a Cloud Tasks API operation with automatic projectId injection.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited