headers property

Map<String, String>? headers
final

HTTP request headers to include in the request to the task queue function.

These headers represent a subset of the headers that will accompany the task's HTTP request. Some HTTP request headers will be ignored or replaced, e.g. Authorization, Host, Content-Length, User-Agent etc. cannot be overridden.

By default, Content-Type is set to 'application/json'.

The size of the headers must be less than 80KB.

Implementation

final Map<String, String>? headers;