delete method
Deletes a task from the queue by its id.
A task can only be deleted if it hasn't been executed yet. If the task doesn't exist, this method completes successfully without error.
Example:
await queue.delete('unique-task-id');
Throws FirebaseFunctionsAdminException if the request fails.
Implementation
Future<void> delete(String id) {
return _requestHandler.delete(id, _functionName, _extensionId);
}