ApsInterruptionLevel enum
The interruption level of an APNs notification, as defined by Apple.
See https://developer.apple.com/documentation/usernotifications/unnotificationinterruptionlevel
Values
- active → const ApsInterruptionLevel
-
The system presents the notification immediately, lights up the screen, and can play a sound.
- critical → const ApsInterruptionLevel
-
The system presents the notification immediately, lights up the screen, and bypasses the mute switch to play a sound. Requires the Critical Alerts entitlement.
- passive → const ApsInterruptionLevel
-
The system adds the notification to the notification list without lighting up the screen or playing a sound.
- timeSensitive → const ApsInterruptionLevel
-
The notification appears immediately and can play a sound, but will not break through Focus or Do Not Disturb.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ApsInterruptionLevel> - A constant List of the values in this enum, in order of their declaration.