Messaging class

An interface for interacting with the Firebase Cloud Messaging service.

Properties

app FirebaseApp
The app associated with this Messaging instance.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete() Future<void>
Cleans up resources used by this service.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(Message message, {bool? dryRun}) Future<String>
Sends the given message via FCM.
sendEach(List<Message> messages, {bool? dryRun}) Future<BatchResponse>
Sends each message in the given array via Firebase Cloud Messaging.
sendEachForMulticast(MulticastMessage message, {bool? dryRun}) Future<BatchResponse>
Sends the given multicast message to all the FCM registration tokens specified in it.
subscribeToTopic(List<String> registrationTokens, String topic) Future<MessagingTopicManagementResponse>
Subscribes a list of registration tokens to an FCM topic.
toString() String
A string representation of this object.
inherited
unsubscribeFromTopic(List<String> registrationTokens, String topic) Future<MessagingTopicManagementResponse>
Unsubscribes a list of registration tokens from an FCM topic.

Operators

operator ==(Object other) bool
The equality operator.
inherited