unsubscribeFromTopic method
Unsubscribes a list of registration tokens from an FCM topic.
See Unsubscribe from a topic for code samples and detailed documentation.
registrationTokens: A list of registration tokens to unsubscribe from the topic.topic: The topic from which to unsubscribe.
Returns a Future fulfilled with the server's response after the registration tokens have been unsubscribed from the topic.
Implementation
Future<MessagingTopicManagementResponse> unsubscribeFromTopic(
List<String> registrationTokens,
String topic,
) {
return _requestHandler.unsubscribeFromTopic(registrationTokens, topic);
}