SecurityRules class

The Firebase SecurityRules service interface.

Properties

app FirebaseApp
The Firebase app this service is associated with.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createRuleset(RulesFile file) Future<Ruleset>
Creates a new Ruleset from the given RulesFile.
delete() Future<void>
Cleans up resources used by this service.
deleteRuleset(String name) Future<void>
Deletes the Ruleset identified by the given name. The input name should be the short name string without the project ID prefix. For example, to delete the projects/project-id/rulesets/my-ruleset, pass the short name "my-ruleset". Rejects with a not-found error if the specified Ruleset cannot be found.
getFirestoreRuleset() Future<Ruleset>
Gets the Ruleset currently applied to Cloud Firestore. Rejects with a not-found error if no ruleset is applied on Firestore.
getRuleset(String name) Future<Ruleset>
Gets the Ruleset identified by the given name. The input name should be the short name string without the project ID prefix. For example, to retrieve the projects/project-id/rulesets/my-ruleset, pass the short name "my-ruleset". Rejects with a not-found error if the specified Ruleset cannot be found.
getStorageRuleset([String? bucket]) Future<Ruleset>
Gets the Ruleset currently applied to a Cloud Storage bucket. Rejects with a not-found error if no ruleset is applied on the bucket.
listRulesetMetadata({int pageSize = 100, String? nextPageToken}) Future<RulesetMetadataList>
Retrieves a page of ruleset metadata.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
releaseFirestoreRuleset(String ruleset) Future<void>
Applies the specified Ruleset ruleset to Cloud Firestore.
releaseFirestoreRulesetFromSource(String source) Future<Ruleset>
Creates a new Ruleset from the given source, and applies it to Cloud Firestore.
releaseStorageRuleset(String ruleset, [String? bucket]) Future<void>
Applies the specified Ruleset ruleset to a Cloud Storage bucket.
releaseStorageRulesetFromSource(String source, [String? bucket]) Future<Ruleset>
Creates a new Ruleset from the given source, and applies it to a Cloud Storage bucket.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited